@extends('layouts.admin')
@section('content')
    <h3 class="page-title"> {{ $title }}
        <small></small>
    </h3>
    <div class="page-bar">
        <ul class="page-breadcrumb">
            <li>
                <i class="icon-home"></i>
                <a href="{{ route('admin.home') }}">Dashboard</a>
                <i class="fa fa-angle-right"></i>
            </li>
            <li>
                <span>{{ $title }}</span>
            </li>
        </ul>
    </div>
    <div class="row">
        <div class="col-md-12">         
            <!-- BEGIN SAMPLE TABLE PORTLET-->
            <div class="portlet light">
                <div class="portlet-title">
                    <div class="caption">
                        <i class="fa fa-edit"></i>
                        <span class="caption-subject">
                            {{ $title }}
                        </span>
                    </div>
                </div>
                <div class="portlet-body form">
                    <form class="form-horizontal" method="POST" id="mainForm">
                        <div class="form-body">
                            @foreach( Config::get('app.languages') as $key => $lang )
                            <div class="form-group @if($errors->has('translate.$key.title')) has-error @endif">
                                <label class="control-label col-md-2">{{$lang}} Title</label>
                                <div class="col-md-10">
                                    <input type="text" name="translate[{{$key}}][title]" class="form-control" id="translate[{{$key}}]title" placeholder="{{$lang}} Title" value="{{  old('translate.$key.title') }}">
                                </div>
                            </div>
                            @endforeach
                            <div class="form-group @if($errors->has('type')) has-error @endif">
                                <label class="control-label col-md-2">Type</label>
                                <div class="col-md-10">
                                    <select name="type" class="form-control select2" id="type">
                                        <option value="1">Normal</option>
                                        <option value="2">Featured</option>
                                    </select>
                                </div>
                            </div>

                            <div class="form-group @if($errors->has('category')) has-error @endif">
                                <label class="control-label col-md-2">Category</label>
                                <div class="col-md-10">
                                    <select name="category" class="form-control select2" id="category">
                                        @foreach($categories as $c)
                                        <option value="{{ $c->id }}" @if( old('category') == $c->id ) selected="selected" @endif>{{ $c->title }}</option>
                                        @endforeach
                                    </select>
                                </div>
                            </div>
                            @foreach( Config::get('app.languages') as $key => $lang )
                            <div class="form-group @if($errors->has('description')) has-error @endif">
                                <label class="control-label col-md-2">{{$lang}} Description</label>
                                <div class="col-md-10">
                                    <textarea name="translate[{{$key}}][description]" class="tinyeditor">{{ old('description') }}</textarea>
                                </div>
                            </div>
                            @endforeach
                            <div class="form-group @if($errors->has('per_bid_price')) has-error @endif">
                                <label class="control-label col-md-2">Price per bids</label>
                                <div class="col-md-10">
                                    <input type="number" name="per_bid_price" class="form-control" id="per_bid_price" placeholder="0.01" value="{{ old('per_bid_price', 0.01) }}" min="0" step="0.01">
                                </div>
                            </div>

                            <div class="form-group @if($errors->has('start_price')) has-error @endif">
                                <label class="control-label col-md-2">Start price</label>
                                <div class="col-md-10">
                                    <input type="number" name="start_price" class="form-control" id="start_price" placeholder="0.00" value="{{ old('start_price', 0.00) }}" min="0">
                                </div>
                            </div>

                            <div class="form-group @if($errors->has('buy_price')) has-error @endif">
                                <label class="control-label col-md-2">Buy it now price</label>
                                <div class="col-md-10">
                                    <input type="number" name="buy_price" class="form-control" id="buy_price" placeholder="0.00" value="{{ old('buy_price', 0.00) }}" min="0">
                                </div>
                            </div>

                                <div class="form-group @if($errors->has('bot_bids_target_price')) has-error @endif">
                                    <label class="control-label col-md-2">Bot bids limit price</label>
                                    <div class="col-md-10">
                                        <input type="number" name="bot_bids_target_price" class="form-control" id="bot_bids_target_price" placeholder="0.00" value="{{ old('bot_bids_target_price', 0.00) }}" min="0" step="0.01">
                                        <small class="text-muted">How high the price can be increased by the bots</small>
                                    </div>
                                </div>




                                <div class="form-group @if($errors->has('user_win_price_limit')) has-error @endif">
                                    <label class="control-label col-md-2">User win price limit</label>
                                    <div class="col-md-10">
                                        <input type="number" name="user_win_price_limit" class="form-control" id="user_win_price_limit" placeholder="0.00" value="{{ old('user_win_price_limit', 0.00) }}" min="0" step="0.01">
                                        <small class="text-muted">Expected income limit, if cyclically reached, user can win the item's next generation</small>
                                    </div>
                                </div>

                                <div class="form-group @if($errors->has('user_bidders_price')) has-error @endif">
                                    <label class="control-label col-md-2">User bidders price</label>
                                    <div class="col-md-10">
                                        <input type="number" name="user_bidders_price" class="form-control" id="user_bidders_price" placeholder="0.00" value="{{ old('user_bidders_price', 0.00) }}" min="0" step="0.01">
                                        <small class="text-muted">Actually real user's investment in the whole last cycles</small>
                                    </div>
                                </div>


                                
                            <div class="form-group @if($errors->has('ends_at')) has-error @endif">
                                <label class="control-label col-md-2">Ends at</label>
                                <div class="col-md-10">
                                  <input type='text' class="form-control" name="ends_at" id='datetimepicker-1' value="{{ old('ends_at', Carbon\Carbon::now()->format('Y-m-d H:i:s')) }}" />
                                  <small class="text-muted">Default: GMT+08:00</small>
                                </div>
                            </div>

                                <div class="form-group @if($errors->has('bot_bids_start_from')) has-error @endif">
                                    <label class="control-label col-md-2">Bot bids start from</label>
                                    <div class="col-md-10">
                                        <input type='text' class="form-control" name="bot_bids_start_from" id='datetimepicker-2' value="{{ old('bot_bids_start_from', Carbon\Carbon::now()->format('Y-m-d H:i:s')) }}" />
                                        <small class="text-muted">Default: GMT+08:00</small>
                                    </div>
                                </div>

                                <div class="form-group @if($errors->has('bot_need_win')) has-error @endif">
                                    <label class="control-label col-md-2">Bot win?</label>
                                    <div class="col-md-10">
                                        <input type="checkbox" class="make-switch" data-size="small" data-on-color="success" data-on-text='<i class="fa fa-check" aria-hidden="true"></i>' data-off-color="default" data-off-text='<i class="fa fa-times" aria-hidden="true"></i>' name="bot_need_win" value="1" @if( old('bot_need_win', 1) == 0 ) @else checked @endif>
                                    </div>
                                </div>
                                <div class="form-group @if($errors->has('auto_renew')) has-error @endif">
                                    <label class="control-label col-md-2">Auto renew</label>
                                    <div class="col-md-10">
                                        <input type="checkbox" class="make-switch" data-size="small" data-on-color="success" data-on-text='<i class="fa fa-check" aria-hidden="true"></i>' data-off-color="default" data-off-text='<i class="fa fa-times" aria-hidden="true"></i>' name="auto_renew" value="1" @if( old('auto_renew', 0) == 0 ) @else checked @endif>
                                    </div>
                                </div>
                            @if( !is_null(old('images', null)) && is_array(old('images')) )
                                @foreach(old('images') as $i)
                                <input type="hidden" name="images[]" value="{{ $i }}" />
                                @endforeach
                            @endif
                            
                        </div>

                        <input type="hidden" name="_token" value="{{ csrf_token() }}">

                        <div class="form-actions">
                            <div class="row">
                                <div class="col-md-offset-2 col-md-10">
                                    <button type="submit" class="btn yellow">
                                        <i class="fa fa-floppy-o"></i> Save
                                    </button>
                                    <a href="{{ route('admin.auction.items') }}" class="btn default">Cancel</a>
                                </div>
                            </div>
                        </div>
                    </form>

                    <form id="fileupload" action="{{ route('admin.ajax.auction.imageUpload', 'items') }}" method="POST" enctype="multipart/form-data">
                        <!-- The fileupload-buttonbar contains buttons to add/delete files and start/cancel the upload -->
                        <div class="row fileupload-buttonbar">
                            <div class="col-lg-7">
                                <!-- The fileinput-button span is used to style the file input field as button -->
                                <span class="btn green fileinput-button">
                                    <i class="fa fa-plus"></i>
                                    <span> Add files... </span>
                                    <input type="file" name="files[]" multiple=""> 
                                </span>
                                <button type="submit" class="btn blue start">
                                    <i class="fa fa-upload"></i>
                                    <span> Start upload </span>
                                </button>
                                <button type="reset" class="btn warning cancel">
                                    <i class="fa fa-ban-circle"></i>
                                    <span> Cancel upload </span>
                                </button>
                                <button type="button" class="btn red delete">
                                    <i class="fa fa-trash"></i>
                                    <span> Delete </span>
                                </button>
                                <!-- The global file processing state -->
                                <span class="fileupload-process"> </span>
                            </div>
                            <!-- The global progress information -->
                            <div class="col-lg-5 fileupload-progress fade">
                                <!-- The global progress bar -->
                                <div class="progress progress-striped active" role="progressbar" aria-valuemin="0" aria-valuemax="100">
                                    <div class="progress-bar progress-bar-success" style="width:0%;">
                                    </div>
                                </div>

                                <!-- The extended global progress information -->
                                <div class="progress-extended"> &nbsp; </div>
                            </div>
                        </div>

                        <!-- The table listing the files available for upload/download -->
                        <table role="presentation" class="table table-striped clearfix">
                            <tbody class="files"> </tbody>
                        </table>
                    </form>

                    <div id="blueimp-gallery" class="blueimp-gallery blueimp-gallery-controls" data-filter=":even">
                        <div class="slides"> </div>
                        <h3 class="title"></h3>
                        <a class="prev"> ‹ </a>
                        <a class="next"> › </a>
                        <a class="close white"> </a>
                        <a class="play-pause"> </a>
                        <ol class="indicator"> </ol>
                    </div>
                    <!-- BEGIN JAVASCRIPTS(Load javascripts at bottom, this will reduce page load time) -->
                    <script id="template-upload" type="text/x-tmpl"> {% for (var i=0, file; file=o.files[i]; i++) { %}
                        <tr class="template-upload fade">
                            <td>
                                <span class="preview"></span>
                            </td>
                            <td>
                                <p class="name">{%=file.name%}</p>
                                <strong class="error label label-danger"></strong>
                            </td>
                            <td>
                                <p class="size">Processing...</p>
                                <div class="progress progress-striped active" role="progressbar" aria-valuemin="0" aria-valuemax="100" aria-valuenow="0">
                                    <div class="progress-bar progress-bar-success" style="width:0%;"></div>
                                </div>
                            </td>
                            <td> {% if (!i && !o.options.autoUpload) { %}
                                <button class="btn blue start" disabled>
                                    <i class="fa fa-upload"></i>
                                    <span>Start</span>
                                </button> {% } %} {% if (!i) { %}
                                <button class="btn red cancel">
                                    <i class="fa fa-ban"></i>
                                    <span>Cancel</span>
                                </button> {% } %} </td>
                        </tr> {% } %} </script>
                    <!-- The template to display files available for download -->
                    <script id="template-download" type="text/x-tmpl"> {% for (var i=0, file; file=o.files[i]; i++) { %}
                        <tr class="template-download fade">
                            <td>
                                <span class="preview"> {% if (file.thumbnailUrl) { %}
                                    <a href="{%=file.url%}" title="{%=file.name%}" download="{%=file.name%}" data-gallery>
                                        <img src="{%=file.thumbnailUrl%}">
                                    </a> {% } %} </span>
                            </td>
                            <td>
                                <p class="name"> {% if (file.url) { %}
                                    <a href="{%=file.url%}" title="{%=file.name%}" download="{%=file.name%}" {%=file.thumbnailUrl? 'data-gallery': ''%}>{%=file.name%}</a> {% } else { %}
                                    <span>{%=file.name%}</span> {% } %} </p> {% if (file.error) { %}
                                <div>
                                    <span class="label label-danger">Error</span> {%=file.error%}</div> {% } %} </td>
                            <td>
                                <span class="size">{%=o.formatFileSize(file.size)%}</span>
                            </td>
                            <td> {% if (file.deleteUrl) { %}
                                <button class="btn red delete btn-sm" data-type="{%=file.deleteType%}" data-url="{%=file.deleteUrl%}" {% if (file.deleteWithCredentials) { %} data-xhr-fields='{"withCredentials":true}'
                                    {% } %}>
                                    <i class="fa fa-trash-o"></i>
                                    <span>Delete</span>
                                </button>
                                <input type="checkbox" name="delete" value="1" class="toggle"> {% } else { %}
                                 {% } %} </td>
                        </tr> {% } %} </script>
                </div>
            </div>
            <!-- END SAMPLE TABLE PORTLET-->
        </div>
    </div>
@stop

@section('style')
<link href="{{ asset('__admin/global/plugins/bootstrap-datetimepicker-2/css/bootstrap-datetimepicker.min.css') }}" rel="stylesheet" type="text/css" />
<link href="{{ asset('__admin/global/plugins/fancybox/source/jquery.fancybox.css') }}" rel="stylesheet" type="text/css" />
<link href="{{ asset('__admin/global/plugins/jquery-file-upload/blueimp-gallery/blueimp-gallery.min.css') }}" rel="stylesheet" type="text/css" />
<link href="{{ asset('__admin/global/plugins/jquery-file-upload/css/jquery.fileupload.css') }}" rel="stylesheet" type="text/css" />
<link href="{{ asset('__admin/global/plugins/jquery-file-upload/css/jquery.fileupload-ui.css') }}" rel="stylesheet" type="text/css" />
@endsection
@section('script')
<script src="{{ asset('__admin/global/plugins/moment/moment.min.js') }}" type="text/javascript"></script>
<!--<script src="{{ asset('__admin/global/plugins/moment/moment-timezone.js') }}" type="text/javascript"></script>-->
<script src="{{ asset('__admin/global/plugins/bootstrap-datetimepicker-2/js/bootstrap-datetimepicker.min.js') }}" type="text/javascript"></script>
<script src="//cdn.tinymce.com/4/tinymce.min.js"></script>
<script src="{{ asset('__admin/global/plugins/fancybox/source/jquery.fancybox.pack.js') }}" type="text/javascript"></script>
<script src="{{ asset('__admin/global/plugins/jquery-file-upload/js/vendor/jquery.ui.widget.js') }}" type="text/javascript"></script>
<script src="{{ asset('__admin/global/plugins/jquery-file-upload/js/vendor/tmpl.min.js') }}" type="text/javascript"></script>
<script src="{{ asset('__admin/global/plugins/jquery-file-upload/js/vendor/load-image.min.js') }}" type="text/javascript"></script>
<script src="{{ asset('__admin/global/plugins/jquery-file-upload/js/vendor/canvas-to-blob.min.js') }}" type="text/javascript"></script>
<script src="{{ asset('__admin/global/plugins/jquery-file-upload/blueimp-gallery/jquery.blueimp-gallery.min.js') }}" type="text/javascript"></script>
<script src="{{ asset('__admin/global/plugins/jquery-file-upload/js/jquery.iframe-transport.js') }}" type="text/javascript"></script>
<script src="{{ asset('__admin/global/plugins/jquery-file-upload/js/jquery.fileupload.js') }}" type="text/javascript"></script>
<script src="{{ asset('__admin/global/plugins/jquery-file-upload/js/jquery.fileupload-process.js') }}" type="text/javascript"></script>
<script src="{{ asset('__admin/global/plugins/jquery-file-upload/js/jquery.fileupload-image.js') }}" type="text/javascript"></script>
<script src="{{ asset('__admin/global/plugins/jquery-file-upload/js/jquery.fileupload-audio.js') }}" type="text/javascript"></script>
<script src="{{ asset('__admin/global/plugins/jquery-file-upload/js/jquery.fileupload-video.js') }}" type="text/javascript"></script>
<script src="{{ asset('__admin/global/plugins/jquery-file-upload/js/jquery.fileupload-validate.js') }}" type="text/javascript"></script>
<script src="{{ asset('__admin/global/plugins/jquery-file-upload/js/jquery.fileupload-ui.js') }}" type="text/javascript"></script>
<script type="text/javascript">
    window.imageStorageUrl = '{{ url("storage/auction/") }}';
</script>
<script type="text/javascript" src="{{ asset('__admin/scripts/pages/auction-items-new.js') }}"></script>
@stop