@extends('layouts.admin')

@section('content')
    <h3 class="page-title"> {{ $title }}
        <small></small>
    </h3>
    <div class="page-bar">
        <ul class="page-breadcrumb">
            <li>
                <i class="icon-home"></i>
                <a href="{{ route('admin.home') }}">{{ $title }}</a>
                <i class="fa fa-angle-right"></i>
            </li>
            <li>
                <span>{{ $title }}</span>
            </li>
        </ul>
    </div>
    <div class="row">
        <div class="col-md-8">
            <div class="portlet light">
                <div class="portlet-title">
                    <div class="caption">
                        <i class="fa fa-envelope"></i>{{ $title }}
                    </div>
                </div>
                <div class="portlet-body form">
                    <form class="form-horizontal" method="post" action="" autocomplete="off" id="sendMail">
                        <div class="form-body">

                            <div class="form-group @if($errors->has('to')) has-error @endif">
                                <label class="col-sm-2 control-label">To</label>
                                <div class="col-sm-10">
                                    <select id="to" name="to" class="form-control">
                                        <option value="0" selected>All members</option>
                                        <option value="1">Members With Inactive Plans</option>
                                        <option value="2">Members With Active Plans</option>
                                        <option value="3">Members Without Plans</option>
                                        <option value="4">Members With Plans</option>
                                        <option value="5">Activated Members</option>
                                        <option value="6">Unactivated Members</option>
                                        <option value="7">Specify List</option>
                                    </select>
                                </div>
                            </div>

                            <div class="form-group hidden @if($errors->has('specify-list')) has-error @endif" id="specify-list-group">
                                <label class="col-sm-2 control-label">Specify List</label>
                                <div class="col-sm-10">
                                    <input name="specify-list" id="user-tagging" class="select2 select2-multiple" type="text" value="1">
                                    <p class="help-block"><em>Type the specified user ID, Username or Email to select</em></p>
                                </div>
                            </div>

                            <div class="form-group @if($errors->has('method')) has-error @endif">
                                <label class="col-sm-2 control-label">Delivery Method</label>
                                <div class="col-sm-10">
                                    <label class="control-inline fancy-checkbox">
                                        <input type="checkbox" value="1" name="method[]">
                                        <span>Email</span>
                                    </label>
                                    <label class="control-inline fancy-checkbox">
                                        <input type="checkbox" value="2" name="method[]">
                                        <span>Internal Mailbox</span>
                                    </label>
                                </div>
                            </div>

                            <div class="form-group @if($errors->has('from_display')) has-error @endif">
                                <label for="from_display" class="col-sm-2 control-label">From Display</label>
                                <div class="col-sm-10">
                                    <input type="text" class="form-control" id="from_display" placeholder="From Display" name="from_display" value="{{ Config::get('mail.from.name') }}">
                                </div>
                            </div>

                            <div class="form-group @if($errors->has('from')) has-error @endif">
                                <label for="from" class="col-sm-2 control-label">From</label>
                                <div class="col-sm-10">
                                    <input type="text" class="form-control" id="from" placeholder="From" name="from" value="{{ Config::get('mail.from.address') }}">
                                </div>
                            </div>

                            <div class="form-group @if($errors->has('subject')) has-error @endif">
                                <label for="subject" class="col-sm-2 control-label">Subject</label>
                                <div class="col-sm-10">
                                    <input type="text" class="form-control" id="subject" placeholder="Subject" name="subject" value="{{ old('subject') }}">
                                </div>
                            </div>

                            <div class="form-group">
                                <label class="col-sm-2 control-label">Stored Templates</label>
                                <div class="col-sm-5">
                                    <select id="stored_templates" name="stored_templates" class="form-control">
                                    @foreach($templates as $t)
                                    <option value="{{ $t->id }}">{{ $t->title }}</option>
                                    @endforeach
                                    </select>
                                </div>
                                <div class="col-sm-3"><a href="#" class="btn btn-primary" id="stored-templates-load"><i class="fa fa-refresh"></i> Load</a></div>
                            </div>

                            <div class="form-group last @if($errors->has('content')) has-error @endif">
                                <label class="control-label col-md-2">Content</label>
                                <div class="col-md-10">
                                    <textarea name="content" class="tinyeditor">{{ old('content') }}</textarea>
                                </div>
                            </div>

                        </div>
                        <div class="form-actions">
                            <input type="hidden" name="_token" value="{{ csrf_token() }}">
                            <button type="button" class="btn blue" data-toggle="modal" data-target="#preview-modal"><i class="fa fa-search"></i> Preview</button>
                            <button type="submit" class="btn red"><i class="fa fa-reply"></i> Send</button>
                        </div>
                    </form>
                </div>
            </div>
        </div>
        <div class="col-md-4">
            <div class="portlet light">
                <div class="portlet-title">
                    <div class="caption">
                        <i class="fa fa-info"></i> Template variables
                    </div>
                </div>
                <div class="portlet-body">
                    <p><em>Use these variables to insert unique details to each emails. Please double check these before you send!</em></p>
                    <ul>
                        <li>User ID - @{{ $id }}</li>
                        <li>First Name - @{{ $first_name }}</li>
                        <li>Last Name - @{{ $last_name }}</li>
                        <li>Username - @{{ $username }}</li>
                        <li>User email - @{{ $email }}</li>
                    </ul>
                </div>
            </div>
        </div>
    </div>
    <div class="modal fade" id="preview-modal" tabindex="-1" role="dialog">
        <div class="modal-dialog modal-wide" role="document">
            <div class="modal-content">
                <div class="modal-header">

                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                    <h4 class="modal-title" id="myModalLabel">E-mail preview</h4>
                </div>
                <div class="modal-body"></div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-dismiss="modal">Close</button>
                </div>
            </div>
        </div>
    </div>
@stop

@section('style')
<link href="{{ asset('__admin/global/plugins/select2/css/select2.min.css') }}" rel="stylesheet" type="text/css" />
<link href="{{ asset('__admin/global/plugins/select2/css/select2-bootstrap.min.css') }}" rel="stylesheet" type="text/css" />

<link href="{{ asset('css/massmailer.css') }}" rel="stylesheet" type="text/css" />

@stop
@section('script')
<script src="//cdn.tinymce.com/4/tinymce.min.js"></script>
<script src="{{ asset('__admin/global/plugins/select2/js/select2.full.min.js') }}" type="text/javascript"></script>
<script type="text/javascript">
var load_content_ajax_url = '{{ route("admin.ajax.massmailer.template") }}';
var user_tagging_ajax_url = '{{ route("admin.ajax.users.search.select2") }}';
var languages= {!! json_encode(Config::get('app.languages')) !!};
</script>
<script type="text/javascript" src="{{ asset('__admin/scripts/pages/massmailer.js') }}"></script>
@stop