@extends('layouts.auth')

@section('style')
<link href="{{ asset('assets/css/pages/login.css') }}" rel="stylesheet" type="text/css" />
@stop

@section('script')
	<script src="{{ asset('assets/global/plugins/moment/moment.min.js') }}"></script>
	<script type="text/javascript">
		$(document).ready(function(){
			$.ajaxSetup({
	        	headers: {
				'X-CSRF-TOKEN': '{{ csrf_token() }}'
	        	}
	    	});

		    var dom = {
		    	sponsor_result: $('#sponsor_result'),
		    	sponsor_code: $('#sponsor_code'),
		    	sponsor_name: $('#sponsor_name')
		    };

		    var resetDom = function( type ) {
		    	if( type == 1 ) {
			    	dom.sponsor_result.addClass('hidden');
			    	dom.sponsor_name.removeClass('hidden');
			    	dom.sponsor_name.html('');
			    	showError('sponsor_result', null, true);
			    }
		    };

		    var showError = function( type, msg, hide ) {
				var error_dom = dom[ type ].find('.error');
				var success_dom = dom[ type ].find('.success');

				success_dom.addClass('hidden');
				dom[ type ].removeClass('hidden');

				if( hide ) {
					error_dom.addClass('hidden');
				} else {
					error_dom.html(msg);
					error_dom.removeClass('hidden');
				}
		    };


		    var sponsor;
			var currentSponsor;
			var sponsorStatus = false;

		    var searchSponsor = function(e) {
				var val = dom.sponsor_code.val();

				if( !val || currentSponsor == val ) return;

				currentSponsor = val;

				$.ajax({
					type: 'POST',
					data: {
						sponsor_code: currentSponsor
					},
					url: '{{ route("ajax.getSponsor") }}',
					success: function( res ) {
						resetDom(1);

						if( !res.result ) {
							sponsorStatus = false;
							showError('sponsor_result', res.message);
							return;
						}

						sponsor = res.sponsor;

						dom.sponsor_name.removeClass('hidden');

						dom.sponsor_name.html( 'You sponsor will be: ' + sponsor.username + ' (#' + sponsor.user_id + ')' );

						dom.sponsor_result.removeClass('hidden');

						sponsorStatus = true;

					},
					error: function( err ) {
						resetDom(1);
						alert('Error: ' + res.message);
						return;
					}
				});
			};

	    	searchSponsor();
	    	//searchUpline();

			$('#sponsor_search_btn').on('click', searchSponsor);
			//$('#upline_user_search_btn').on('click', searchUpline);

			$('form#reg-form').submit( function (e) {

				var sponsor_val = dom.sponsor_code.val();
				//var upline_val = dom.upline_user.val();

				if( ( sponsor_val !== '' && !sponsorStatus) || ( sponsor_val == '' && sponsorStatus) ) {
					e.preventDefault();
					alert('If you fill the sponsor field, please press the search button to find a valid sponsor before sending the registration form.');
					return;
				}

				/*if( ( upline_val !== '' && !uplineStatus) || ( upline_val == '' && uplineStatus) ) {
					e.preventDefault();
					alert('If you fill the sponsor field, please press the search button to find a valid upline user before sending the registration form.');
					return;
				}*/

				//$(this).submit();

			});

			$('.btnUpdPrdct').on('click', function(){
				var self = $(this);


				$('.btnUpdPrdct.active').removeClass('active');
				self.addClass('active');

				$('input[name="package"]').val( self.data('id') );
			});
		});
	</script>
@stop


@section('content')
<!-- BEGIN LOGO -->
<div class="logo">
    <a href="{{ route('site.index') }}">
        <img src="{{ asset('images/logo.png') }}" alt="" /> 
    </a>
</div>
<!-- END LOGO -->
<!-- BEGIN LOGIN -->
<div class="content">
	  <!-- BEGIN LOGIN FORM -->
	<form class="register-form" action="" method="post">
		<h3 class="font-green">{{ trans('register.title') }}</h3>

		@include('shared.messages')
		@if(env('MLM') == 'ON')
		<div class="row">
			<div class="col-xs-12 panel-group"></div>

			@foreach( $packages as $p )
				<div class="col-md-4 col-sm-4 col-xs-12">
					<div class="thumbnail text-center">
						<h1 class="lead text-uppercase"> {{ $p->name }} </h1>
						<img src="{{ asset('images/icons/' . $p->icon) }}" alt="{{ $p->name }}" class="img-responsive center-block form-group">
						<span style="font-family:'Segoe UI','Trebuchet MS','Calibri','Arial','sans-serif'">{{ $p->description }}</span>

						<br>

						<div class="lead">$ {{ $p->price }}</div>
						<button type="button" class="btn btn-block btn-default btnUpdPrdct @if( ($cart->content()->count() > 0 && $cart->content()->first()->id == $p->id) || old('package', $selectedPackage) == $p->id ) active @endif" data-id="{{ $p->id }}">Buy</button>
					</div>
				</div>
			@endforeach

		</div>
		@endif

	  <fieldset>
			<legend>{{ trans('register.account') }}</legend>

		  <div class="form-group {{ $errors->has('username') ? 'has-error' : '' }}">
		      <label class="control-label visible-ie8 visible-ie9">{{ trans('auth.register_form.username') }}</label>
		      <input class="form-control placeholder-no-fix" type="text" autocomplete="off" placeholder="{{ trans('auth.register_form.username') }}" name="username" value="{{ Input::old('username') }}" />
		  </div>
		  <div class="form-group {{ $errors->has('password') ? 'has-error' : '' }}">
		      <label class="control-label visible-ie8 visible-ie9">{{ trans('auth.register_form.password') }}</label>
		      <input class="form-control placeholder-no-fix" type="password" autocomplete="off" id="register_password" placeholder="{{ trans('auth.register_form.password') }}" name="password" />
		  </div>
		  <div class="form-group {{ $errors->has('password_confirm') ? 'has-error' : '' }}">
		      <label class="control-label visible-ie8 visible-ie9">{{ trans('auth.register_form.repassword') }}</label>
		      <input class="form-control placeholder-no-fix" type="password" autocomplete="off" placeholder="{{ trans('auth.register_form.repassword') }}" name="password_confirm" />
		  </div>
		  @if(env('MLM') == 'ON')
			  <div class="form-group {{ $errors->has('secondary_password') ? 'has-error' : '' }}">
				  <label class="control-label visible-ie8 visible-ie9">{{ trans('auth.register_form.secondaryPassword') }}</label>
				  <input class="form-control placeholder-no-fix" type="password" autocomplete="off" id="register_password" placeholder="{{ trans('auth.register_form.secondaryPassword') }}" name="secondary_password" />
			  </div>
			  <div class="form-group {{ $errors->has('secondary_password_confirm') ? 'has-error' : '' }}">
				  <label class="control-label visible-ie8 visible-ie9">{{ trans('auth.register.reSecondaryPassword') }}</label>
				  <input class="form-control placeholder-no-fix" type="password" autocomplete="off" placeholder="{{ trans('auth.register_form.reSecondaryPassword') }}" name="secondary_password_confirm" />
			  </div>
		  @endif
	 	</fieldset>

	  <fieldset>
			<legend>{{ trans('register.personal') }}</legend>

		  <div class="form-group {{ $errors->has('first_name') ? 'has-error' : '' }}">
		      <label class="control-label visible-ie8 visible-ie9">{{ trans('register.first_name') }}</label>
		      <input class="form-control placeholder-no-fix" type="text" placeholder="{{ trans('register.first_name') }}" name="first_name" value="{{ Input::old('first_name') }}" />
		  </div>

		  <div class="form-group {{ $errors->has('last_name') ? 'has-error' : '' }}">
		      <label class="control-label visible-ie8 visible-ie9">{{ trans('register.last_name') }}</label>
		      <input class="form-control placeholder-no-fix" type="text" placeholder="{{ trans('register.last_name') }}" name="last_name" value="{{ Input::old('last_name') }}" />
		  </div>

		  <div class="form-group {{ $errors->has('email') ? 'has-error' : '' }}">
		      <!--ie8, ie9 does not support html5 placeholder, so we just show field title for that-->
		      <label class="control-label visible-ie8 visible-ie9">{{ trans('register.email') }}</label>
		      <input class="form-control placeholder-no-fix" type="text" placeholder="{{ trans('register.email') }}" name="email" value="{{ Input::old('email') }}" /> </div>

	  </fieldset>

		@if($sponsor)
	  	<fieldset>
			<legend>Sponsor</legend>

			<div class="form-group {{ $errors->has('sponsor_code') ? 'has-error' : '' }}">
        		<label class="control-label visible-ie8 visible-ie9">Sponsor user</label>
        		<div class="input-group">
        			<span class="input-group-addon"><i class="fa fa-users"></i></span>
          			<input type="text" class="form-control" id="sponsor_code" placeholder="sponsor user" name="sponsor_code" readonly value="{{ Input::old('sponsor_code', $ref) }}" />
   				</div>
      		</div>

		</fieldset>
		@endif
		<hr />

	  <div class="form-group margin-top-20 margin-bottom-20">
		  <label class="check">
		      <input type="checkbox" name="agreement" value="1" {{ (Input::old('agreement') == '1') ? ' checked="checked"' : '' }}>{{ trans('auth.register_form.aggree') }}
		  </label>
		  <br>
		  <small>{{ trans('auth.register_form.aggreeText') }}
			</small>
		  <div id="register_tnc_error"> </div>
	  </div>

	  <hr />

		<div class="form-group">
			<div class="col-sm-12 col-md-12 col-lg-5" style="text-align:center">
	        <img src="{{ url('captcha/image') }}" style="width:140px;text-align:center" />
	    </div>
	    <div class="col-sm-12 col-md-12 col-lg-7" style="margin-top: 0px">
	      <input type="text" name="captcha" placeholder="{{ trans('register.captcha') }}" id="captcha" class="form-control">
	    </div>
	  </div>

	  <div class="form-actions">
	  	<input type="hidden" name="_token" value="{{ csrf_token() }}">
	  	<input type="hidden" name="package" value="{{ old('package', $selectedPackage) }}">
	  	@if( $useUpline )
	  		<input type="hidden" name="uplineUserId" value="{{ Input::get('uid') }}">
	  		<input type="hidden" name="preferredLeg" value="{{ Input::get('l') }}">
	  	@endif
	    <button type="submit" id="register-submit-btn" class="btn btn-success uppercase pull-right">{{ trans('register.title') }}</button>
	  </div>
	</form>
</div>
@stop
